@@ -41,6 +41,19 @@ MeeGoHelper::MeeGoHelper(QObject *parent) :
 
     QDBusConnection::systemBus().connect(QString(), "/com/nokia/csd/call", "com.nokia.csd.Call", "Coming", this, SLOT(callEvent(QDBusObjectPath,QString)));
     QDBusConnection::systemBus().connect(QString(), "/com/nokia/csd/call", "com.nokia.csd.Call", "Created", this, SLOT(callEvent(QDBusObjectPath,QString)));
+
+    Settings settings;
+    // Load stored hosts
+    foreach(const XbmcHost &host, settings.hostList()) {
+        int index = Xbmc::instance()->hostModel()->insertOrUpdateHost(host);
+        if(host.address() == settings.lastHost().address()) {
+            qDebug() << "reconnecting to" << host.hostname() << host.address() << host.username() << host.password();
+            Xbmc::instance()->hostModel()->connectToHost(index);
+        }
+    }
+
+    connect(Xbmc::instance(), SIGNAL(connectedChanged(bool)), SLOT(connectionChanged(bool)));
+
 }
 
 bool MeeGoHelper::eventFilter(QObject *obj, QEvent *event)
@@ -70,6 +83,8 @@ void MeeGoHelper::keyEvent(MeeGo::QmKeys::Key key, MeeGo::QmKeys::State state)
     case MeeGo::QmKeys::VolumeDown:
         Xbmc::instance()->setVolume(Xbmc::instance()->volume() - 5);
         break;
+    default:
+        break;
     }
 }
 
@@ -100,3 +115,13 @@ void MeeGoHelper::callTerminated()
         Xbmc::instance()->videoPlayer()->playPause();
     }
 }
+
+void MeeGoHelper::connectionChanged(bool connected)
+{
+    if(connected) {
+        Settings settings;
+        settings.addHost(*Xbmc::instance()->connectedHost());
+        settings.setLastHost(*Xbmc::instance()->connectedHost());
+    }
+
+}
