@@ -22,6 +22,7 @@ protected:
     void keyPressEvent(QKeyEvent* event);
 
 private slots:
+    void orientationChanged();
     void openSettingsDialog();
     void openConnectDialog();
     void openAboutDialog();
@@ -32,11 +33,12 @@ private slots:
     void callTerminated();
 #endif
 
-private:
+    void authenticationRequired(const QString &hostname, const QString &address);
+    void connectionChanged(bool connected);
 
+private:
     QmlApplicationViewer *viewer;
     Settings *m_settings;
-
 };
 
 #endif // MAINWINDOW_H
