@@ -31,6 +31,7 @@ Movies::Movies(XbmcModel *parent) :
     QVariantMap params;
     QVariantList properties;
     properties.append("fanart");
+    properties.append("playcount");
     params.insert("properties", properties);
 
     QVariantMap sort;
@@ -102,6 +103,7 @@ void Movies::responseReceived(int id, const QVariantMap &rsp)
 
     switch(m_requestList.value(id)) {
     case RequestList: {
+        setBusy(false);
         QList<XbmcModelItem*> list;
         qDebug() << "got movies:" << rsp.value("result");
         QVariantList responseList = rsp.value("result").toMap().value("movies").toList();
@@ -111,6 +113,7 @@ void Movies::responseReceived(int id, const QVariantMap &rsp)
             item->setTitle(itemMap.value("label").toString());
             item->setMovieId(itemMap.value("movieid").toInt());
             item->setThumbnail(itemMap.value("fanart").toString());
+            item->setPlaycount(itemMap.value("playcount").toInt());
             item->setIgnoreArticle(true);
             item->setFileType("file");
             item->setPlayable(true);
