@@ -31,6 +31,7 @@ MusicVideos::MusicVideos(XbmcModel *parent) :
     QVariantMap params;
     QVariantList properties;
     properties.append("fanart");
+    properties.append("playcount");
     params.insert("properties", properties);
 
     QVariantMap sort;
@@ -83,6 +84,7 @@ void MusicVideos::responseReceived(int id, const QVariantMap &rsp)
 
     switch(m_requestList.value(id)) {
     case RequestList: {
+        setBusy(false);
         QList<XbmcModelItem*> list;
         qDebug() << "got MusicCideos:" << rsp.value("result");
         QVariantList responseList = rsp.value("result").toMap().value("musicvideos").toList();
@@ -92,6 +94,7 @@ void MusicVideos::responseReceived(int id, const QVariantMap &rsp)
             item->setTitle(itemMap.value("label").toString());
             item->setMusicvideoId(itemMap.value("musicvideoid").toInt());
             item->setThumbnail(itemMap.value("fanart").toString());
+            item->setPlaycount(itemMap.value("playcount").toInt());
             item->setIgnoreArticle(false);
             item->setFileType("file");
             item->setPlayable(true);
