@@ -35,7 +35,8 @@ Seasons::Seasons(int tvshowid, XbmcModel *parent):
     QVariantList properties;
     properties.append("showtitle");
     properties.append("season");
-    properties.append("fanart");
+    properties.append("thumbnail");
+    properties.append("playcount");
     params.insert("properties", properties);
 
     QVariantMap sort;
@@ -53,6 +54,7 @@ void Seasons::responseReceived(int id, const QVariantMap &rsp)
         return;
     }
 
+    setBusy(false);
     QList<XbmcModelItem*> list;
     qDebug() << "got Seasons:" << rsp.value("result");
     QVariantList responseList = rsp.value("result").toMap().value("seasons").toList();
@@ -62,7 +64,8 @@ void Seasons::responseReceived(int id, const QVariantMap &rsp)
         item->setTitle(itemMap.value("label").toString());
         item->setSubtitle(itemMap.value("showtitle").toString());
         item->setSeasonId(itemMap.value("season").toInt());
-        item->setThumbnail(itemMap.value("fanart").toString());
+        item->setThumbnail(itemMap.value("thumbnail").toString());
+        item->setPlaycount(itemMap.value("playcount").toInt());
         item->setIgnoreArticle(false);
         item->setFileType("directory");
         item->setPlayable(false);
