@@ -17,8 +17,10 @@
  ****************************************************************************/
 
 #include "xbmc.h"
+#include "xbmchostmodel.h"
 #include "xbmcconnection.h"
 #include "xdebug.h"
+#include "xbmcdiscovery.h"
 
 #include "audiolibrary.h"
 #include "artists.h"
@@ -56,7 +58,11 @@ Xbmc *Xbmc::instance()
 }
 
 Xbmc::Xbmc(QObject *parent) :
-    QObject(parent)
+    QObject(parent),
+    m_canShutdown(false),
+    m_canReboot(false),
+    m_canHibernate(false),
+    m_canSuspend(false)
 {
     qmlRegisterType<AudioLibrary>();
     qmlRegisterType<VideoLibrary>();
@@ -79,18 +85,17 @@ Xbmc::Xbmc(QObject *parent) :
 
     qmlRegisterType<AudioPlayer>("Xbmc", 1, 0, "Player");
 
-    QSettings settings("xbmcremote");
-    m_hostname = settings.value("Host").toString();
-    m_port = settings.value("Port", 8080).toInt();
-    m_username = settings.value("Username").toString();
-    m_password = settings.value("Password").toString();
+    qmlRegisterType<XbmcHostModel>();
+    qmlRegisterType<XbmcDiscovery>("Xbmc", 1, 0, "XbmcDiscovery");
 
-    XbmcConnection::connect(m_hostname, m_port, m_username, m_password);
-//    XbmcConnection::connect("10.10.10.10", 8080);
+    QSettings settings("xbmcremote");
+
+    m_hosts = new XbmcHostModel(this);
 
     connect(XbmcConnection::notifier(), SIGNAL(connectionChanged()), SLOT(connectionChanged()));
     connect(XbmcConnection::notifier(), SIGNAL(receivedAnnouncement(QVariantMap)), SLOT(parseAnnouncement(QVariantMap)));
     connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
+    connect(XbmcConnection::notifier(), SIGNAL(authenticationRequired(QString,QString)), SIGNAL(authenticationRequired(QString, QString)));
 
     m_audioPlayer = new AudioPlayer(this);
     m_videoPlayer = new VideoPlayer(this);
@@ -121,6 +126,15 @@ void Xbmc::init()
     int id = XbmcConnection::sendCommand("Application.GetProperties", params);
     m_requestMap.insert(id, RequestVolume);
 
+    params.clear();
+    list.clear();
+    list.append("canshutdown");
+    list.append("canhibernate");
+    list.append("cansuspend");
+    list.append("canreboot");
+    params.insert("properties", list);
+    id = XbmcConnection::sendCommand("System.GetProperties", params);
+    m_requestMap.insert(id, RequestSystemProperties);
 }
 
 bool Xbmc::connected()
@@ -128,6 +142,16 @@ bool Xbmc::connected()
     return XbmcConnection::connected();
 }
 
+XbmcHost *Xbmc::connectedHost()
+{
+    return XbmcConnection::connectedHost();
+}
+
+void Xbmc::setAuthCredentials(const QString &username, const QString &password)
+{
+    XbmcConnection::setAuthCredentials(username, password);
+}
+
 QString Xbmc::connectionError()
 {
     return XbmcConnection::connectionError();
@@ -163,61 +187,9 @@ PicturePlayer *Xbmc::picturePlayer()
     return m_picturePlayer;
 }
 
-QString Xbmc::hostname()
+XbmcHostModel *Xbmc::hostModel()
 {
-    return m_hostname;
-}
-
-void Xbmc::setHostname(const QString &hostname)
-{
-    QSettings settings("xbmcremote");
-    settings.setValue("Host", hostname);
-    m_hostname = hostname;
-    emit hostnameChanged();
-}
-
-int Xbmc::port(){
-    qDebug() << "port" << m_port;
-    return m_port;
-}
-
-void Xbmc::setPort(int port)
-{
-    QSettings settings("xbmcremote");
-    settings.setValue("Port", port);
-    m_port = port;
-    emit portChanged();
-}
-
-QString Xbmc::username()
-{
-    return m_username;
-}
-
-void Xbmc::setUsername(const QString &username)
-{
-    QSettings settings("xbmcremote");
-    settings.setValue("Username", username);
-    m_username = username;
-    emit usernameChanged();
-}
-
-QString Xbmc::password()
-{
-    return m_password;
-}
-
-void Xbmc::setPassword(const QString &password)
-{
-    QSettings settings("xbmcremote");
-    settings.setValue("Password", password);
-    m_password = password;
-    emit passwordChanged();
-}
-
-void Xbmc::connectToHost()
-{
-    XbmcConnection::connect(m_hostname, m_port, m_username, m_password);
+    return m_hosts;
 }
 
 Player *Xbmc::activePlayer()
@@ -284,14 +256,25 @@ void Xbmc::responseReceived(int id, const QVariantMap &response)
 //        qDebug() << "Volume received" << m_volume;
         emit volumeChanged(m_volume);
         break;
-
+    case RequestSystemProperties:
+        qDebug() << "Got system properties:" << rsp.toMap();
+        m_canShutdown = rsp.toMap().value("canshutdown").toBool();
+        m_canReboot = rsp.toMap().value("canreboot").toBool();
+        m_canHibernate = rsp.toMap().value("canhibernate").toBool();
+        m_canSuspend = rsp.toMap().value("cansuspend").toBool();
+        emit systemPropertiesChanged();
+        qDebug() << m_canShutdown << m_canReboot << m_canHibernate << m_canSuspend;
     }
 
 }
 
 QString Xbmc::vfsPath()
 {
-    return XbmcConnection::vfsPath();
+    if(XbmcConnection::connectedHost()) {
+        //xDebug(XDAREA_CONNECTION) << "returning vfs:" << "http://" + m_hostName + ':' + QString::number(m_port) + "/vfs/";
+        return "http://" + XbmcConnection::connectedHost()->address() + ':' + QString::number(XbmcConnection::connectedHost()->port()) + "/vfs/";
+    }
+    return QString();
 }
 
 QString Xbmc::state()
@@ -350,6 +333,26 @@ void Xbmc::quit()
     XbmcConnection::sendCommand("Application.Quit");
 }
 
+void Xbmc::suspend()
+{
+    XbmcConnection::sendCommand("System.Suspend");
+}
+
+void Xbmc::hibernate()
+{
+    XbmcConnection::sendCommand("System.Hibernate");
+}
+
+void Xbmc::shutdown()
+{
+    XbmcConnection::sendCommand("System.Shutdown");
+}
+
+void Xbmc::reboot()
+{
+    XbmcConnection::sendCommand("System.Reboot");
+}
+
 void Xbmc::dimVolumeTo(int newVolume)
 {
     m_volumeAnimation.setDirection(QAbstractAnimation::Forward);
@@ -374,3 +377,21 @@ void Xbmc::queryActivePlayers()
     int id = XbmcConnection::sendCommand("Player.GetActivePlayers");
     m_requestMap.insert(id, RequestActivePlayer);
 }
+
+bool Xbmc::canShutdown()
+{
+    return m_canShutdown;
+}
+
+bool Xbmc::canReboot()
+{
+    return m_canReboot;
+}
+bool Xbmc::canHibernate()
+{
+    return m_canHibernate;
+}
+bool Xbmc::canSuspend()
+{
+    return m_canSuspend;
+}
