@@ -29,14 +29,25 @@
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QAuthenticator>
+#include <QHostInfo>
 
 #define DEBUGJSON
 
 namespace XbmcConnection
 {
-void connect(const QString &hostname, int port, const QString &username, const QString &password)
+void connect(XbmcHost *host)
 {
-    instance()->connect(hostname, port, username, password);
+    instance()->connect(host);
+}
+
+XbmcHost *connectedHost()
+{
+    return instance()->connectedHost();
+}
+
+void setAuthCredentials(const QString &username, const QString &password)
+{
+    instance()->setAuthCredentials(username, password);
 }
 
 int sendCommand(const QString &command, const QVariant &params)
@@ -44,11 +55,6 @@ int sendCommand(const QString &command, const QVariant &params)
    return instance()->sendCommand(command, params);
 }
 
-QString vfsPath()
-{
-    return instance()->vfsPath();
-}
-
 Notifier *notifier()
 {
     return instance()->notifier();
@@ -82,7 +88,8 @@ XbmcConnectionPrivate::XbmcConnectionPrivate(QObject *parent) :
     QObject(parent),
     m_commandId(0),
     m_versionRequestId(-1),
-    m_connected(false)
+    m_connected(false),
+    m_host(0)
 {
     m_socket = new QTcpSocket();
     m_notifier = new XbmcConnection::Notifier();
@@ -101,23 +108,25 @@ XbmcConnectionPrivate::XbmcConnectionPrivate(QObject *parent) :
     QObject::connect(m_network, SIGNAL(authenticationRequired(QNetworkReply*,QAuthenticator*)), SLOT(authenticationRequired(QNetworkReply*,QAuthenticator*)));
 }
 
-void XbmcConnectionPrivate::connect(const QString &hostname, int port, const QString &username, const QString &password)
+void XbmcConnectionPrivate::connect(XbmcHost *host)
 {
     m_socket->disconnectFromHost();
 
-    m_hostName = hostname;
-    m_port = port;
-    m_username = username;
-    m_password = password;
+    m_host = host;
 
-    xDebug(XDAREA_CONNECTION) << "connecting to" << hostname;
+    xDebug(XDAREA_CONNECTION) << "connecting to" << host->hostname() << host->address() << host->username() << host->password();
     // We connect to telnet on port 9090 for the announcements
-    m_socket->connectToHost(hostname, 9090);
+    m_socket->connectToHost(host->address(), 9090);
 
-    m_connectionError = "Connecting to " + hostname + "...";
+    m_connectionError = "Connecting to " + host->hostname() + "...";
     emit m_notifier->connectionChanged();
 }
 
+XbmcHost* XbmcConnectionPrivate::connectedHost()
+{
+    return m_host;
+}
+
 void XbmcConnectionPrivate::slotConnected()
 {
     xDebug(XDAREA_CONNECTION) << "Connected to remote host. Asking for version...";
@@ -151,23 +160,17 @@ void XbmcConnectionPrivate::socketError()
     emit m_notifier->connectionChanged();
 }
 
-QString XbmcConnectionPrivate::vfsPath()
-{
-//    xDebug(XDAREA_CONNECTION) << "returning vfs:" << "http://" + m_hostName + ':' + QString::number(m_port) + "/vfs/";
-    return "http://" + m_hostName + ':' + QString::number(m_port) + "/vfs/";
-}
-
 void XbmcConnectionPrivate::sendNextCommand2() {
 
     if(m_currentPendingCommand.id() >= 0 || m_socket->state() != QAbstractSocket::ConnectedState) {
-//        xDebug(XDAREA_CONNECTION) << "cannot send... busy";
+        xDebug(XDAREA_CONNECTION) << "cannot send... busy";
         return;
     }
     if(m_commandQueue.count() > 0) {
         Command command = m_commandQueue.takeFirst();
 
         QNetworkRequest request;
-        request.setUrl(QUrl("http://" + m_hostName + ":" + QString::number(m_port) + "/jsonrpc"));
+        request.setUrl(QUrl("http://" + m_host->address() + ":" + QString::number(m_host->port()) + "/jsonrpc"));
 
         QVariantMap map;
         map.insert("jsonrpc", "2.0");
@@ -204,7 +207,8 @@ void XbmcConnectionPrivate::replyReceived()
         emit m_notifier->connectionChanged();
     }
 
-//    xDebug(XDAREA_CONNECTION) << "received reply:" << commands;
+    qDebug() << "received reply:" << commands;
+    xDebug(XDAREA_CONNECTION) << "received reply:" << commands;
 
     QStringList commandsList = commands.split("}{");
 
@@ -401,7 +405,7 @@ void XbmcConnectionPrivate::clearPending()
     xDebug(XDAREA_CONNECTION) << "timeouttimer hit for comman" << m_commandId;
     if(m_commandId == m_versionRequestId) {
         xDebug(XDAREA_CONNECTION) << "cannot ask for remote version... ";
-        m_connectionError = "Connection to " + m_hostName + " timed out...";
+        m_connectionError = "Connection to " + m_host->hostname() + " timed out...";
         emit m_notifier->connectionChanged();
         m_commandQueue.clear();
     }
@@ -428,12 +432,24 @@ void XbmcConnectionPrivate::authenticationRequired(QNetworkReply *reply, QAuthen
 {
     if(reply == m_lastAuthRequest) {
         m_connectionError = "Wrong username or password";
-        emit m_notifier->connectionChanged();
+//        emit m_notifier->connectionChanged();
+//        emit m_notifier->authenticationRequired(m_host->hostname(), m_host->address());
     }
-    if(!m_username.isEmpty() && !m_password.isEmpty()) {
-        authenticator->setUser(m_username);
-        authenticator->setPassword(m_password);
+    if(!m_host->username().isEmpty() && !m_host->password().isEmpty()) {
+        authenticator->setUser(m_host->username());
+        authenticator->setPassword(m_host->password());
         m_lastAuthRequest = reply;
+    } else {
+        emit m_notifier->authenticationRequired(m_host->hostname(), m_host->address());
+    }
+}
+
+void XbmcConnectionPrivate::setAuthCredentials(const QString &username, const QString &password)
+{
+    if(m_host) {
+        m_host->setUsername(username);
+        m_host->setPassword(password);
+        connect(m_host);
     }
 }
 
